#!/bin/sh -x
# build script for fakeroot
# built on tc-7.x


pkgname=fakeroot
pkgver=1.18.4
#pkgver=1.20.2
source="http://ftp.debian.org/debian/pool/main/f/${pkgname}/${pkgname}_${pkgver}.orig.tar.bz2"
#pkgdir="/tmp/${pkgname}_install"
pkgdir="/usr/local"

## load build deps
tceinstalled='/usr/local/tce.installed'
tcepath='/etc/sysconfig/tcedir/optional'
kerbuild=$(uname -r)


deps="compiletc.tcz \
bash.tcz \
glib2-dev.tcz \
wget.tcz \
filesystems-${kerbuild}.tcz \
sed.tcz  \
pkg-config.tcz  \
libtool-dev.tcz \
acl-dev.tcz \
util-linux.tcz"


for i in `echo $deps`; do 

depname=`basename "$i" .tcz`

# check if tcz installed already
if [ -f ${tceinstalled}/"$depname" ]; then
	echo "${WHITE}"$i" ${GREEN}Already loaded${NORMAL}"

else
	if  [ ! -f ${tceinstalled}/"$depname" ]; then

# tcz not installed, then install from local path
	if [ -f ${tcepath}/"$i" ]; then
	  while [ ! -f ${tceinstalled}/"$depname" ]; do
	    tce-load -i "$depname"; sleep 0.5
	  done
		if [ -f ${tceinstalled}/"$depname" ]; then
			echo "${CYAN}"$i" ${BLUE}loaded locally${NORMAL}"
		fi

# tcz not downloaded, install from repo
	elif [ ! -f ${tcepath}/"$i" ]; then
	    tce-load -wil "$depname"; sleep 0.5
		if [ -f ${tceinstalled}/"$depname" ]; then
			echo "${MAGENTA}"$i" ${YELLOW}downloaded from repo${NORMAL}"
		fi
	fi
	fi
fi

if [ ! -f "${tceinstalled}/$depname" ]; then
	echo "${RED}$i failed to load, exiting..${NORMAL}"; exit 8
fi

done

sleep 1


mkdir /tmp/${pkgname}
cd /tmp/${pkgname}
wget $source

if [ -f ${pkgname}*.bz2 ]; then
	tar -vxjf ${pkgname}*.bz2
else
   echo -e "\n\nerror... "
   exit 9 
fi

kerarch=$(uname -m)
set +x; echo -e "\n\n ${BLUE}Export compiler flags... ${NORMAL}"; set -x
if [ x"$kerarch" == xx86_64 ]; then
# x86_64
echo "compile flags for $kerarch"
export CFLAGS="-mtune=generic -Os -pipe"
export CXXFLAGS="-mtune=generic -Os -pipe -fno-exceptions -fno-rtti"
else
# x86
echo "compile flags for $kerarch"
export CFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export CXXFLAGS="-march=i486 -mtune=i686 -Os -pipe"
fi

cd $pkgname-$pkgver

./configure --prefix=/usr/local --libdir=/usr/local/lib/libfakeroot --disable-static --with-ipc=sysv

find . -name Makefile -type f -exec sed -i 's/-O2//g' {} \;

sudo touch /tmp/NOW
sleep 5

#make DESTDIR="$pkgdir" install
sudo make install

cd /
sudo install -dm775 ${pkgdir}/etc/ld.so.conf.d/
echo -e "/usr/local/lib/libfakeroot" > /tmp/fakeroot.conf
sudo mv /tmp/fakeroot.conf /usr/local/etc/ld.so.conf.d/fakeroot.conf

cd /usr/local/bin
sudo strip --strip-debug --strip-unneeded faked

## additional optional commands
[ -d /home/tc/${pkgname}_raw ] || mkdir -p /home/tc/${pkgname}_raw
sudo find /usr -newer /tmp/NOW -not -type d > /home/tc/${pkgname}_raw/${pkgname}_raw.list
sudo find /etc -newer /tmp/NOW -not -type d >> /home/tc/${pkgname}_raw/${pkgname}_raw.list
sudo find /lib -newer /tmp/NOW -not -type d | grep /lib/modules/${kerbuild}/kernel/drivers/ >> /home/tc/${pkgname}_raw/${pkgname}_raw.list
cd /home/tc/${pkgname}_raw
tar -T ${pkgname}_raw.list -czvf ${pkgname}_raw.tar.gz

exit
